by Edgar Allan Poe (published 1849)

Thank Heaven! the crisis --  
    The danger is past,  
And the lingering illness  
    Is over at last --  
And the fever called "Living"  
    Is conquered at last.

Sadly, I know  
    I am shorn of my strength,  
And no muscle I move  
    As I lie at full length --  
But no matter! -- I feel  
    I am better at length.

And I rest so composedly,  
    Now, in my bed,  
That any beholder  
    Might fancy me dead --  
Might start at beholding me,  
    Thinking me dead.

The moaning and groaning,  
    The sighing and sobbing,  
Are quieted now,  
    With that horrible throbbing  
At heart: -- ah, that horrible,  
    Horrible throbbing!

The sickness -- the nausea --  
    The pitiless pain --  
Have ceased, with the fever  
    That maddened my brain --  
With the fever called "Living"  
    That burned in my brain.

And oh! of all tortures  
    That torture the worst  
Has abated -- the terrible  
    Torture of thirst  
For the naphthaline river  
    Of Passion accurst: --  
I have drank of a water  
    That quenches all thirst: --

Of a water that flows,  
    With a lullaby sound,  
From a spring but a very few  
    Feet under ground --  
From a cavern not very far  
    Down under ground.

And ah! let it never  
    Be foolishly said  
That my room it is gloomy  
    And narrow my bed;  
For man never slept  
    In a different bed --  
And, to sleep, you must slumber  
    In just such a bed.

My tantalized spirit  
    Here blandly reposes,  
Forgetting, or never  
    Regretting its roses --  
Its old agitations  
    Of myrtles and roses:

For now, while so quietly  
    Lying, it fancies  
A holier odor  
    About it, of pansies --  
A rosemary odor,  
    Mixed with pansies --  
With rue and the beautiful  
    Puritan pansies.

And so it lies happily,  
    Bathing in many  
A dream of the truth  
    And the beauty of Annie --  
Drowned in a bath  
    Of the tresses of Annie.

She tenderly kissed me,  
    She fondly caressed,  
And then I fell gently  
    To sleep on her breast --  
Deeply to sleep  
    From the heaven of her breast.

When the light was extinguished,  
    She covered me warm,  
And she prayed to the angels  
    To keep me from harm --  
To the queen of the angels  
    To shield me from harm.

And I lie so composedly,  
    Now, in my bed,  
(Knowing her love)  
    That you fancy me dead --  
And I rest so contentedly,  
    Now in my bed,  
(With her love at my breast)  
    That you fancy me dead --  
That you shudder to look at me,  
    Thinking me dead: --

But my heart it is brighter  
    Than all of the many  
Stars in the sky,  
    For it sparkles with Annie --  
It glows with the light  
    Of the love of my Annie --  
With the thought of the light  
    Of the eyes of my Annie.